==> mvapich2-2.2rc2.tar.gz: mvapich2-2.2rc2/src/mpi/coll/tuning/scatter/gen2_RI2_28ppn.h <==
#define GEN2__RI2__28PPN {		\
	{		\
	56,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{2, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{512, &MPIR_Scatter_MV2_Binomial},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Direct},		\
	{128, &MPIR_Scatter_MV2_Direct},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	112,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	224,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8192, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	448,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8192, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Binomial},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	896,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{2, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{4, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{8, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8192, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Binomial},		\
	{1024, &MPIR_Scatter_MV2_Binomial},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	}		 \
}

==> mvapich2-2.3rc1.tar.gz: mvapich2-2.3rc1/src/mpi/coll/tuning/scatter/gen2_RI2_2ppn.h <==
#define GEN2__RI2__2PPN {		\
	{		\
	2,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Binomial},		\
	{1024, &MPIR_Scatter_MV2_Binomial},		\
	{2048, &MPIR_Scatter_MV2_Binomial},		\
	{4096, &MPIR_Scatter_MV2_Binomial},		\
	{8192, &MPIR_Scatter_MV2_Binomial},		\
	{16384, &MPIR_Scatter_MV2_Binomial},		\
	{32768, &MPIR_Scatter_MV2_Binomial},		\
	{65536, &MPIR_Scatter_MV2_Binomial},		\
	{131072, &MPIR_Scatter_MV2_Binomial},		\
	{262144, &MPIR_Scatter_MV2_Binomial},		\
	{524288, &MPIR_Scatter_MV2_Binomial},		\
	{1048576, &MPIR_Scatter_MV2_two_level_Binomial}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Direct},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Direct},		\
	{16, &MPIR_Scatter_MV2_Direct},		\
	{32, &MPIR_Scatter_MV2_Direct},		\
	{64, &MPIR_Scatter_MV2_Direct},		\
	{128, &MPIR_Scatter_MV2_Direct},		\
	{256, &MPIR_Scatter_MV2_Direct},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Binomial}		\
	}		\
	},		 \
	{		\
	4,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Direct},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Direct},		\
	{64, &MPIR_Scatter_MV2_Direct},		\
	{128, &MPIR_Scatter_MV2_Direct},		\
	{256, &MPIR_Scatter_MV2_Direct},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Direct},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Direct},		\
	{16, &MPIR_Scatter_MV2_Direct},		\
	{32, &MPIR_Scatter_MV2_Direct},		\
	{64, &MPIR_Scatter_MV2_Direct},		\
	{128, &MPIR_Scatter_MV2_Direct},		\
	{256, &MPIR_Scatter_MV2_Direct},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	8,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Direct},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Direct},		\
	{128, &MPIR_Scatter_MV2_Direct},		\
	{256, &MPIR_Scatter_MV2_Direct},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Binomial},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	16,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Direct},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	32,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16, &MPIR_Scatter_MV2_two_level_Direct},		\
	{32, &MPIR_Scatter_MV2_two_level_Direct},		\
	{64, &MPIR_Scatter_MV2_two_level_Direct},		\
	{128, &MPIR_Scatter_MV2_two_level_Direct},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8192, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Direct},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Direct},		\
	{4096, &MPIR_Scatter_MV2_Direct},		\
	{8192, &MPIR_Scatter_MV2_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	},		 \
	{		\
	64,		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{2, &MPIR_Scatter_MV2_Binomial},		\
	{4, &MPIR_Scatter_MV2_Binomial},		\
	{8, &MPIR_Scatter_MV2_Binomial},		\
	{16, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{32, &MPIR_Scatter_MV2_Binomial},		\
	{64, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{128, &MPIR_Scatter_MV2_two_level_Binomial},		\
	{256, &MPIR_Scatter_MV2_two_level_Direct},		\
	{512, &MPIR_Scatter_MV2_two_level_Direct},		\
	{1024, &MPIR_Scatter_MV2_two_level_Direct},		\
	{2048, &MPIR_Scatter_MV2_two_level_Direct},		\
	{4096, &MPIR_Scatter_MV2_two_level_Direct},		\
	{8192, &MPIR_Scatter_MV2_two_level_Direct},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	},		\
	21,		\
	{		\
	{1, &MPIR_Scatter_MV2_Direct},		\
	{2, &MPIR_Scatter_MV2_Direct},		\
	{4, &MPIR_Scatter_MV2_Direct},		\
	{8, &MPIR_Scatter_MV2_Direct},		\
	{16, &MPIR_Scatter_MV2_Binomial},		\
	{32, &MPIR_Scatter_MV2_Direct},		\
	{64, &MPIR_Scatter_MV2_Binomial},		\
	{128, &MPIR_Scatter_MV2_Binomial},		\
	{256, &MPIR_Scatter_MV2_Binomial},		\
	{512, &MPIR_Scatter_MV2_Direct},		\
	{1024, &MPIR_Scatter_MV2_Direct},		\
	{2048, &MPIR_Scatter_MV2_Binomial},		\
	{4096, &MPIR_Scatter_MV2_Binomial},		\
	{8192, &MPIR_Scatter_MV2_Binomial},		\
	{16384, &MPIR_Scatter_MV2_Direct},		\
	{32768, &MPIR_Scatter_MV2_Direct},		\
	{65536, &MPIR_Scatter_MV2_Direct},		\
	{131072, &MPIR_Scatter_MV2_Direct},		\
	{262144, &MPIR_Scatter_MV2_Direct},		\
	{524288, &MPIR_Scatter_MV2_Direct},		\
	{1048576, &MPIR_Scatter_MV2_Direct}		\
	}		\
	}		 \
}
